@@ -1,10 +1,12 @@
 import os
 from os import path as op
 import getpass
+import json
 import tempfile
 import time
 import shutil
 import zipfile
+
 from selenium import webdriver
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.keys import Keys
@@ -42,24 +44,8 @@ class PPMIDownloader:
         (3) prompting the user.
         """
         # Ids of the download checkboxes in the PPMI metadata download page
-        self.file_ids = {
-            "Demographics.csv": 2544,
-            "Age_at_visit.csv": 2834,
-            "REM_Sleep_Behavior_Disorder_Questionnaire.csv": 2472,
-            "Magnetic_Resonance_Imaging__MRI_.csv": 2655,
-            "MDS_UPDRS_Part_III.csv": 2796,
-            "Socio-Economics.csv": 2576,
-            "Montreal_Cognitive_Assessment__MoCA_.csv": 2712,
-            "Age_of_Parkinson_s_Disease_Diagnosis__Online_.csv": 2853,
-            "PD_Diagnosis_History.csv": 2588,
-            "PPMI_Original_Cohort_BL_to_Year_5_Dataset_Apr2020.csv": 2203,
-            "Participant_Status.csv": 2543,
-            "Inclusion_Exclusion.csv": 2696,
-            "Inclusion_Exclusion-Archived.csv": 34,
-            "Concomitant_Medication_Log.csv": 2701,
-            "MRI_Metadata.csv": 2583,
-            "Cognitive_Categorization.csv": 2708,
-        }
+        with open(Path(__file__).parent.joinpath("file_id.json").resolve()) as fin:
+            self.file_ids = json.load(fin)
         self.config_file = config_file
         self.__set_credentials()
 
@@ -126,9 +112,9 @@ class PPMIDownloader:
         * headless: if False, run Chrome not headless
         * timeout: file download timeout, in seconds
         * destination_dir: directory where to store the downloaded files
-        * type: can be 'archived' or 'nifti'. Archived means that the images are downloaded as archived in the PPMI database, which usually means in DICOM format.
+        * type: can be 'archived' or 'nifti'. Archived means that the images are
+        downloaded as archived in the PPMI database, which usually means in DICOM format.
         """
-
         assert type in (
             "archived",
             "nifti",
@@ -248,8 +234,16 @@ class PPMIDownloader:
         self.html.click_button('//*[@id="imgProtocol_checkBox1.Acquisition_Type.3D"]')
         # Click T1 checkbox
         self.html.click_button('//*[@id="imgProtocol_checkBox1.Weighting.T1"]')
-        # Click checkbox to display visit name in resuls
+        # Click checkbox to display visit name in results
         self.html.click_button('//*[@id="RESET_VISIT.0"]')
+        # Click checkbox to display study date in results
+        self.html.click_button('//*[@id="RESET_STUDY.0"]')
+        # Click checkbox to display field strength in results
+        self.html.click_button(
+            '//*[@id="RESET_PROTOCOL_NUMERIC.imgProtocol_1_Field_Strength"]'
+        )
+        # Click checkbox to display acquisition plane in results
+        self.html.click_button('//*[@id="RESET_PROTOCOL_STRING.1_Acquisition_Plane"]')
 
         # Click search button
         self.html.click_button('//*[@id="advSearchQuery"]')
@@ -372,6 +366,7 @@ class HTMLHelper:
     def login(self, email, password):
         self.driver.get("https://ida.loni.usc.edu/login.jsp?project=PPMI")
         self.click_button("ida-cookie-policy-accept", BY=By.CLASS_NAME)
+        time.sleep(3)
         self.click_button("ida-user-menu-icon", BY=By.CLASS_NAME)
 
         self.enter_data("userEmail", email, BY=By.NAME)
@@ -456,7 +451,6 @@ class PPMINiftiFileFinder:
         * image_id: Image id of the image. Example: 123456.
         * description: Protocol description of the image. Example: "MPRAGE GRAPPA"
         """
-
         tree = ET.parse(xml_file)
         root = tree.getroot()
 
@@ -526,12 +520,14 @@ class PPMINiftiFileFinder:
 
     def find_nifti(self, subject_id, event_id, description):
         """
-        Find the nifti file associated with subject, event and protocol description in the finder's download directory.
+        Find the nifti file associated with subject, event and protocol description
+        in the finder's download directory.
         Raise an exception if file is not found: make sure you know what you're looking for!
 
         Parameters:
         * subject_id: Subject id of the sought file.
-        * event_id: Event id of the file. Example: "V06". Warning: this is not the image visit id but a one-to-one mapping exists (see self.visit_map).
+        * event_id: Event id of the file. Example: "V06". Warning: this is not the
+         image visit id but a one-to-one mapping exists (see self.visit_map).
         * description: Protocol description of the file. Example: "MPRAGE GRAPPA".
 
         Return values:
@@ -540,7 +536,12 @@ class PPMINiftiFileFinder:
         """
 
         def clean_desc(desc):
-            return desc.replace(" ", "_").replace("(", "_").replace(")", "_").replace("/", "_")
+            return (
+                desc.replace(" ", "_")
+                .replace("(", "_")
+                .replace(")", "_")
+                .replace("/", "_")
+            )
 
         subject_id = str(subject_id)
 
